@@ -1,16 +1,16 @@
-#define QT_FEATURE_sse2 -1
+#define QT_FEATURE_sse2 1
 #define QT_FEATURE_alloca_h 1
 #define QT_FEATURE_alloca 1
 #define QT_FEATURE_alloca_malloc_h -1
 #define QT_FEATURE_android_style_assets -1
-#define QT_FEATURE_avx2 -1
+#define QT_FEATURE_avx2 1
 #define QT_FEATURE_private_tests -1
 #define QT_FEATURE_dbus -1
 #define QT_FEATURE_dbus_linked -1
 #define QT_FEATURE_dlopen 1
 #define QT_FEATURE_gc_binaries -1
 #define QT_FEATURE_gui -1
-#define QT_FEATURE_intelcet -1
+#define QT_FEATURE_intelcet 1
 #define QT_FEATURE_libudev 1
 #define QT_FEATURE_network 1
 #define QT_FEATURE_posix_fallocate 1
